@@ -21,8 +21,19 @@ import subprocess
 
 
 def execute(command, shell=True):
-    out = subprocess.check_output( command,
-                                   stderr=subprocess.STDOUT,
-                                   shell=shell )
+    try:
+        out = subprocess.check_output( command,
+                                       stderr=subprocess.STDOUT,
+                                       shell=shell )
+    except Exception as e:
+        out = e.output
+
+    try :
+        # python 3
+        out = out.decode("utf-8") 
+    except :
+        # python 2.7
+        pass
+        
     return out
 
