@@ -21,10 +21,11 @@ from __future__ import print_function
 
 
 import os
-import treep_git
-import status
-import coloring
-from console_manager import Console_manager
+
+from . import treep_git
+from . import status
+from . import coloring
+from .console_manager import Console_manager
 
 
 class UnknownProject(Exception):
@@ -74,13 +75,13 @@ class Projects :
 
         if self._conflicts_repositories:
             print(coloring.b_orange("\t\tREPOSITORIES:"))
-            for repo,folders in self._conflicts_repositories.iteritems():
+            for repo,folders in self._conflicts_repositories.items():
                 print("\t\t\t"+coloring.cyan(repo)+" defined in "+", ".join(folders))
             print('')
             
         if self._conflicts_projects:
             print(coloring.b_orange("\t\tprojects:"))
-            for project,folders in self._conflicts_projects.iteritems():
+            for project,folders in self._conflicts_projects.items():
                 print("\t\t\t"+coloring.cyan(project)+" defined in "+", ".join(folders))
             print('')
 
@@ -138,7 +139,7 @@ class Projects :
 
 
     def get_names(self):
-        return self.get_projects_names() + self.get_repos_names()
+        return list(self.get_projects_names()) + list(self.get_repos_names())
     
     def get_repos(self,project_name):
 
@@ -218,7 +219,7 @@ class Projects :
 
     def get_repo_path(self,repo_name):
 
-        return self.get_repos_paths([repo_name]).values()[0]
+        return list(self.get_repos_paths([repo_name]).values())[0]
         
 
     def add_and_commit(self,
@@ -454,9 +455,17 @@ class Projects :
             try :
                 instance = self.get_repo(repo)
                 absolute_path = self.get_repo_path(repo)
-                treep_git.pull(absolute_path)
+                out = treep_git.pull(absolute_path)
                 if console:
-                    print (coloring.green("OK"))
+                    if not "up-to-date" in out:
+                        print (coloring.green("OK"))
+                        out_str =  out[2:-1].split('\\n')
+                        for line in out_str:
+                            line_ = line.strip()
+                            if line_:
+                                print("\t\t\t"+str(line_))
+                    else :
+                        print (coloring.dim("(was up to date)"))
             except Exception as e :
                 if console:
                     print (coloring.red("ERROR"))
@@ -516,18 +525,18 @@ class Projects :
 
         if console or return_common_branches:
             if len(repo_branches.values())>0 :
-                common_branches = repo_branches.values()[0].intersection(*[s for s in repo_branches.values()])
+                common_branches = list(repo_branches.values())[0].intersection(*[s for s in repo_branches.values()])
             else :
                 commong_branches = set()
 
         if len(repo_branches.values())>0 :
-            all_branches = repo_branches.values()[0].union(*[s for s in repo_branches.values()])
+            all_branches = list(repo_branches.values())[0].union(*[s for s in repo_branches.values()])
         else :
             all_branches = set()
             
         if console:
             print('')
-            for repo,branches in repo_branches.iteritems():
+            for repo,branches in repo_branches.items():
                 branches_str = [coloring.green(branch) if branch in common_branches
                                 else branch for branch in branches]
                 print ("\t\t"+coloring.cyan(repo)+": "+" ".join(branches_str))
@@ -567,7 +576,7 @@ class Projects :
 
         repo_paths = self.get_repos_paths(cloned_repos)
 
-        for repo_name,path in repo_paths.iteritems():
+        for repo_name,path in repo_paths.items():
 
             if console:
                 print("\t\t"+coloring.cyan(repo_name)+" ... ",end='')
