@@ -17,7 +17,7 @@
 #    along with Treep.  If not, see <https://www.gnu.org/licenses/>.
 
 
-import coloring
+from . import coloring
 
 
 class Repository(object):
